
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "EKGbuffer.h"


/* Konstruktor */
EKGbuffer::EKGbuffer( int n ) 
{
  B.reserve( n );
  float* tripel;
  for ( int i = 0; i < n; i++ )
  {
    tripel = new float[3];
    tripel[0] = tripel[1] = tripel[2] = 0;
    B.push_back( tripel );
  }
}


/** Kopierkonstruktor */
EKGbuffer::EKGbuffer( const EKGbuffer & buf )
{
  int n = buf.size();
  B.reserve( n );
  float* tripel;
  for ( int i = 0; i < n; i++ )
  {
    tripel = new float[3];
    tripel[0] = buf[i][0];
    tripel[1] = buf[i][1];
    tripel[2] = buf[i][2];
    B.push_back( tripel );
  }
}


/* destruktor */
EKGbuffer::~EKGbuffer()
{
  for ( unsigned int i =  0; i < B.size(); i++ )
    delete[] B[i];
  B.clear();
}


/* Lscht erstes Element und fgt neues hinten an. */
void EKGbuffer::input( float * d )
{
  float* tripel = B[0];
  B.erase( B.begin() );
  for ( int i = 0; i < 3; i++ )
    tripel[i] = d[i];
  B.push_back( tripel );  
  EKGdevice::input( d );
}


/* ndert die Gre des Puffers auf n*/
void EKGbuffer::resize( unsigned int n )
{
  float* tripel;
  if ( n == B.size() ) return;
  if ( n > B.size() ) // Verlngern
  {
    while ( n > B.size() )
    {
      tripel = new float[3];
      tripel[0] = tripel[1] = tripel[2] = 0;
      B.insert( B.begin(), tripel );
    }
  }
  else // Verkrzen
  {
    while ( n < B.size() )
    {
      delete[] B[0];
      B.erase( B.begin() );
    }
  }
}

/* Lscht alle Werte. Ersetzt durch 0. */
void EKGbuffer::reset()
{
  for ( unsigned int i = 0; i < B.size(); i++ )
    B[i][0] = B[i][1] = B[i][2] = 0;
}

