
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef EKGLOGGER_H
#define EKGLOGGER_H

#include <iostream>
#include <string>
#include <time.h>
#include "EKGdevice.h"
#include "EKGtools.h"
#include "calibrate.h"
using namespace std;

/**
 * Diese Klasse schreibt einen Datenstrom direkt in einen ostream. Es
 * werden die Felder Zeit, I, II, III, aVR, aVL und aVF durch TAB getrennt
 * aufgezeichnet. Vor die Daten wird ein Header mit Aufnahmedatum und
 * Patientendaten geschrieben.
 *
 * @author Lars Stollenwerk, Februar 2003
 */
class EKGlogger : public EKGdevice
{
  public:
    /// Konstruktor
    EKGlogger() : log(false), step(0) {}
    /** 
     * Startet das Logging und schreibt Header. 
     *
     * @param name Name und Geb. Datum des Patienten
     * @param o Ausgabestrom.
     */
    void start( const string & name, ostream & o );
    /// Hlt Logging an.
    void stop(){ log = false; }
    /// berschrieben aus EKGdevice
    virtual void input( float * d );
  private:
    /// Ausgabestrom
    ostream * out;
    /// Flag: Loggin ein
    bool log;
    /// Zhler fr Zeitschritte
    unsigned long step;
};

#endif
