
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "EKGplotter.h"
#include "pstemplate.c"

// ----------------------------------------------------------------------
// 
// Postscript
//
// ----------------------------------------------------------------------


/* Ausgabe als Postscript */
void EKGplotter::toPostscript( ostream & o )
{
  int i = 0;
  time_t now_t = time( NULL );
  char * now = ctime( & now_t );
  now[24] = 0; // \n lschen
  writestrings( pstemplate, i, o );
  o << "%%For: " << name << endl;
  o << "%%CreationDate: " << now << endl;
  writestrings( pstemplate, ++i ,o );
  o << '(' << now << "    Patient: " << name << ')' << endl;
  writestrings( pstemplate, ++i ,o );
  writedata( B, 0, o );
  writestrings( pstemplate, ++i ,o );
  writedata( B, 1, o );
  writestrings( pstemplate, ++i ,o );
  writedata( B, 2, o );
  writestrings( pstemplate, ++i ,o );
  writeavr( B, o );
  writestrings( pstemplate, ++i ,o );
  writeavl( B, o );
  writestrings( pstemplate, ++i ,o );
  writeavf( B, o );
  writestrings( pstemplate, ++i ,o );
  o << ts << endl;
  writestrings( pstemplate, ++i ,o );
  o.precision( 2 );
  o << "(" << ts << " mm/s    " << vs << " mm/mV)" << endl;
  writestrings( pstemplate, ++i ,o );
}

// ----------------------------------------------------------------------
// 
// Raw
//
// ----------------------------------------------------------------------

void EKGplotter::toRaw( ostream & o )
{
  time_t now_t = time( NULL );
  char * now = ctime( & now_t );
  now[24] = 0; // \n lschen
  
  o << "# Date: " << now << endl;
  o << "# Patient: " << name << endl;
  o << "#" << endl;
  o << "# Time\tI\tII\tIII\taVR\taVL\taVF" << endl;
  o << "#" << endl;
  o.precision( 5 );
  for ( int i = 0; i < B.size(); i++ )
  {
    o << ( i * EKG_TimeStep ) << '\t';
    o << B[i][0] << '\t' << B[i][1] << '\t' << B[i][2] << '\t';
    o << aVL( B[i] ) << '\t' << aVR( B[i] ) << '\t' << aVF( B[i] ) << endl;
  }
}

// ----------------------------------------------------------------------
//
// Private Methoden
// 
// ----------------------------------------------------------------------

/* Aus Vorlage in stream schreiben */
void EKGplotter::writestrings( const char ** const s, int & i, ostream & o )
{
  while ( s[i][0] )
    o << s[i++] << endl;
}



/* Daten in stream schreiben */
void EKGplotter::writedata( EKGbuffer b, int n, ostream & o )
{
  if ( b.size() == 0 ) return;
  // 5 Stellen reichen in der Ausgabe: 123.45
  o.precision( 5 );
  int max_time_step = timesteps_on_paper( ts );
  int oldest_data = b.size() - max_time_step;
  o << "0 mm " << b[oldest_data][n] * vs << " mm  m" << endl;
  for ( int i = 0; i < max_time_step; i++ )
    o << i * EKG_TimeStep * ts << " mm " << b[i+oldest_data][n] * vs << " mm l" << endl;
}



// aVR schreiben
void EKGplotter::writeavr( EKGbuffer b, ostream & o )
{
  if ( b.size() == 0 ) return;
  // 5 Stellen reichen in der Ausgabe: 123.45
  o.precision( 5 );
  int max_time_step = timesteps_on_paper( ts );
  int oldest_data = b.size() - max_time_step;
  o << "0 mm " << aVR( b[oldest_data] ) * vs << " mm  m" << endl;
  for ( int i = 0; i < max_time_step; i++ )
    o << i * EKG_TimeStep * ts << " mm " << aVR( b[i+oldest_data] ) * vs << " mm l" << endl;
}



// aVL schreiben
void EKGplotter::writeavl( EKGbuffer b, ostream & o )
{
  if ( b.size() == 0 ) return;
  // 5 Stellen reichen in der Ausgabe: 123.45
  o.precision( 5 );
  int max_time_step = timesteps_on_paper( ts );
  int oldest_data = b.size() - max_time_step;
  o << "0 mm " << aVL( b[oldest_data] ) * vs << " mm  m" << endl;
  for ( int i = 0; i < max_time_step; i++ )
    o << i * EKG_TimeStep * ts << " mm " << aVL( b[i+oldest_data] ) * vs << " mm l" << endl;
}



// aVF schreiben
void EKGplotter::writeavf( EKGbuffer b, ostream & o )
{
  if ( b.size() == 0 ) return;
  // 5 Stellen reichen in der Ausgabe: 123.45
  o.precision( 5 );
  int max_time_step = timesteps_on_paper( ts );
  int oldest_data = b.size() - max_time_step;
  o << "0 mm " << aVF( b[oldest_data] ) * vs << " mm  m" << endl;
  for ( int i = 0; i < max_time_step; i++ )
    o << i * EKG_TimeStep * ts << " mm " << aVF( b[i+oldest_data] ) * vs << " mm l" << endl;
}

