
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GEKGFREQ_H
#define GEKGFREQ_H

#include <gtk--/eventbox.h>
#include <gtk--/frame.h>
#include <gtk--/pixmap.h>
#include <gtk--/box.h>
#include <gtk--/label.h>
#include <gtk--/main.h>
#include <unistd.h>
#include <sstream>
#include "EKGfreq.h"
using namespace std;


/**
 * Graphischer Pulszhler. Es werden alle Funktionen von EKGfreq
 * implementiert. Zustzlich handelt es sich bei dieser Klasse um ein
 * GTK-Widget, das den Puls anzeigt.
 *
 * @author Lars Stollenwerk, November 2002
 */
class gEKGfreq : public EKGfreq, public Gtk::EventBox
{
  public:
    /** Konstruktor */
    gEKGfreq();
    /**
     * berschreibt EKGfreq::input(). Zuerst wird die alte Methode
     * aufgerufen, dann wird die Uhr heruntergezhlt.
     */
    virtual void input( float * d );
    /**
     * Kleines Herz zeigen, aber letzten Pulswert beibehalten.
     */
    void reset();
  private:
    /** Frame */
    Gtk::Frame frame;
    /** Box zum Anordnen */
    Gtk::HBox hBox;
    /** Stellt die Pulsfrequent dar. */
    Gtk::Label Pulse;
    /** Enthlt groes Herz. */
    Gtk::Pixmap Heart_bg;
    /** Enthlt kleines Herz. */
    Gtk::Pixmap Heart_sm;
    /** 
     * Uhr fr groes Herz. Hier werden die Datenpakete gezhlt, bis das
     * Herz wieder klein wird. 
     */
    int Hcount;
    /// Aufblinkdauer fr das groe Herz in Sekunden.
    static const float Htime = 0.2;
    /**
     * berschreibt EKGfreq::handleQRS(). Zuerst wird die alte Methode
     * aufgerufen, dann wird die Pipe benachrichtigt.
     */
    virtual void handleQRS();
    // ----------------------------------------------------------------------
    // Threadkommunikation
    // ----------------------------------------------------------------------
    /**
     * Pipe zur Treadkommunikation
     */
    int Pipe[2];
    /**
     * Aktualisiert Label
     */
    void drawRealtime( gint fd, GdkInputCondition /* not used */ );    
    /**
     * Gre eines Datenpaketes im Pipe.
     */
    static const int psize = sizeof(int);
};


#endif

